@@ -1169,11 +1169,19 @@ class Update(MethodsInterface):
         hosts = self.clVars.Get("update.cl_update_binhost_host")
         if not hosts:
             self.clVars.Delete('cl_update_binhost', location="system")
-            raise UpdateError("Binhost is unavailable")
+            raise UpdateError(_("Update server is unavailable"))
         if write_binhost:
             if hosts[0] != self.clVars.Get('update.cl_update_binhost'):
                 self.refresh_binhost = True
             self.clVars.Write('cl_update_binhost', hosts[0], location="system")
+            new_ts = self.clVars.Get("update.cl_update_binhost_timestamp")
+            if new_ts:
+                new_ts = new_ts[0]
+                old_ts = self.clVars.Get("update.cl_update_last_timestamp")
+                if new_ts.isdigit() and (not old_ts.isdigit() or
+                                                 int(new_ts) > int(old_ts)):
+                    ini = SystemIni(self.clVars)
+                    ini.setVar('update', {'last_update': new_ts})
         return True
 
     def message_binhost_changed(self):
@@ -1201,9 +1209,9 @@ class Update(MethodsInterface):
                     changes = True
                 self.clVars.Set(varname, new_value, force=True)
             if not changes:
-                raise UpdateError("Binhost is unavailable")
+                raise UpdateError(_("Update server is unavailable"))
         except DataVarsError:
-            raise UpdateError("Binhost is unavailable")
+            raise UpdateError(_("Update server is unavailable"))
         return True
 
     def drop_binhosts(self, dv):
